## About the library
The project performs a word count of the text you enter. This can be attached in .txt, .epub and .mobi format. In addition, it currently works with both English and Spanish text.The count can be performed taking into account words such as articles, conjunctions and prepositions or omitting them.

## Functionalities
1. Read texts
2. Clean text and omit articles, conjunctions and prepositions.
3. Count words

## Dependencies
- epub_conversion: Processing of epub files
- mobi: Processinf of mobi files

## How to get it
The source code is hosted on: https://github.com/iratigaritano/bookish. 

The installers for the latest released version are available at: https://pypi.org/project/bookish/

Command to install the package:
```sh
# Install
pip install bookish
```

Command to update the package:

```sh
# Update
pip install bookish --upgrade
```

## Authors
Javier Ortega (javier.ortega@alumni.mondragon.edu)

Irati Garitano (irati.garitano@alumni.mondragon.edu)
